@@ -23,8 +23,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#ifndef __EOG_CLOSE_CONFIRMATION_DIALOG_H__
-#define __EOG_CLOSE_CONFIRMATION_DIALOG_H__
+#pragma once
 
 #include <glib.h>
 #include <gtk/gtk.h>
@@ -44,7 +43,7 @@ typedef struct _EogCloseConfirmationDialogPrivate 	EogCloseConfirmationDialogPri
 
 struct _EogCloseConfirmationDialog
 {
-	GtkDialog parent;
+	GtkMessageDialog parent;
 
 	/*< private > */
 	EogCloseConfirmationDialogPrivate *priv;
@@ -52,7 +51,7 @@ struct _EogCloseConfirmationDialog
 
 struct _EogCloseConfirmationDialogClass
 {
-	GtkDialogClass parent_class;
+	GtkMessageDialogClass parent_class;
 };
 
 /**
@@ -93,5 +92,3 @@ GList		*eog_close_confirmation_dialog_get_selected_images	(EogCloseConfirmationD
 G_GNUC_INTERNAL
 void		 eog_close_confirmation_dialog_set_sensitive		(EogCloseConfirmationDialog *dlg, gboolean value);
 
-#endif /* __EOG_CLOSE_CONFIRMATION_DIALOG_H__ */
-
