@@ -59,12 +59,6 @@ struct _EogImagePrivate {
 	guchar           *exif_chunk;
 	guint             exif_chunk_len;
 
-#if 0
-	/* Holds IPTC raw data */
-	guchar           *iptc_chunk;
-	guint             iptc_chunk_len;
-#endif
-
 	gboolean          modified;
 	gboolean          file_is_changed;
 
