@@ -26,6 +26,7 @@
 #include "eog-jobs.h"
 #include "eog-thumbnail.h"
 #include "eog-pixbuf-util.h"
+#include "eog-util.h"
 
 #include <gio/gio.h>
 
@@ -559,6 +560,7 @@ static void
 eog_job_load_run (EogJob *job)
 {
 	EogJobLoad *job_load;
+	gboolean result;
 
 	/* initialization */
 	g_return_if_fail (EOG_IS_JOB_LOAD (job));
@@ -572,14 +574,21 @@ eog_job_load_run (EogJob *job)
 	}
 
 	/* load image from file */
-	eog_image_load (job_load->image,
-			job_load->data,
-			job,
-			&job->error);
+	result = eog_image_load (job_load->image,
+				 job_load->data,
+				 job,
+				 &job->error);
 
 	/* check if the current job was previously cancelled */
-	if (eog_job_is_cancelled (job))
+	if (eog_job_is_cancelled (job)) {
+		if (result) {
+			/* If the load finished successfully we need to make
+			 * the image drop the loaded data again. See #288. */
+			eog_image_data_ref (job_load->image);
+			eog_image_data_unref (job_load->image);
+		}
 		return;
+	}
 
 	/* --- enter critical section --- */
 	g_mutex_lock (job->mutex);
@@ -731,7 +740,9 @@ filter_files (GSList *files, GList **file_list, GList **error_list)
 			GError *error = NULL;
 
 			file_info = g_file_query_info (file,
-						       G_FILE_ATTRIBUTE_STANDARD_TYPE","G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
+						       G_FILE_ATTRIBUTE_STANDARD_TYPE","
+						       G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE","
+						       G_FILE_ATTRIBUTE_STANDARD_FAST_CONTENT_TYPE,
 						       0, NULL, &error);
 			if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_NOT_MOUNTED)) {
 				GMountOperation *operation;
@@ -759,7 +770,7 @@ filter_files (GSList *files, GList **file_list, GList **error_list)
 				if (G_UNLIKELY (type == G_FILE_TYPE_UNKNOWN)) {
 					const gchar *ctype;
 
-					ctype = g_file_info_get_content_type (file_info);
+					ctype = eog_util_get_content_type_with_fallback (file_info);
 
 					/* If the content type is supported
 					   adjust the file_type */
