@@ -133,6 +133,23 @@ eog_sidebar_set_page (EogSidebar   *eog_sidebar,
 	g_object_notify (G_OBJECT (eog_sidebar), "current-page");
 }
 
+gint
+eog_sidebar_get_page_nr (EogSidebar *eog_sidebar)
+{
+	GtkNotebook *notebook = GTK_NOTEBOOK (eog_sidebar->priv->notebook);
+
+	return gtk_notebook_get_current_page (notebook);
+}
+
+void
+eog_sidebar_set_page_nr (EogSidebar   *eog_sidebar,
+		         gint          index)
+{
+	GtkNotebook *notebook = GTK_NOTEBOOK (eog_sidebar->priv->notebook);
+
+	gtk_notebook_set_current_page (notebook, index);
+}
+
 static GtkWidget *
 eog_sidebar_get_current_page (EogSidebar *sidebar)
 {
@@ -418,8 +435,7 @@ eog_sidebar_init (EogSidebar *eog_sidebar)
 	g_signal_connect (close_button, "clicked",
 			  G_CALLBACK (eog_sidebar_close_clicked_cb),
 			  eog_sidebar);
-	/* TODO: i18n */
-	gtk_widget_set_tooltip_text (close_button, "Hide sidebar");
+	gtk_widget_set_tooltip_text (close_button, _("Hide sidebar"));
 
 	image = gtk_image_new_from_icon_name ("window-close-symbolic",
 					      GTK_ICON_SIZE_MENU);
