@@ -23,8 +23,7 @@
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
-#ifndef EOG_ZOOM_ENTRY_H
-#define EOG_ZOOM_ENTRY_H
+#pragma once
 
 #include <glib.h>
 #include <glib-object.h>
@@ -37,5 +36,3 @@
 G_DECLARE_FINAL_TYPE(EogZoomEntry, eog_zoom_entry, EOG, ZOOM_ENTRY, GtkBox);
 
 GtkWidget* eog_zoom_entry_new (EogScrollView *view, GMenu *menu);
-
-#endif /* EOG_ZOOM_ENTRY_H */
