@@ -14,13 +14,12 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#ifndef ZOOM_H
-#define ZOOM_H
+#pragma once
 
 #include <glib.h>
 
@@ -34,5 +33,3 @@ G_GNUC_INTERNAL
 double zoom_fit_scale (guint dest_width, guint dest_height,
 		       guint src_width, guint src_height,
 		       gboolean upscale_smaller);
-
-#endif
